/* tslint:disable:no-console */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const benchmark_1 = require("benchmark");
const _ = require("lodash");
const rxjs_1 = require("rxjs");
const iterate_1 = require("../iterate");
const suite = new benchmark_1.Suite();
// Simulate iterating over a very lage Set of strings and applying a filter on it, then taking only the first 1000 elements
// Smart implementations should only apply the filter predicate to the first 5 elements
const hugeSet = new Set();
for (let i = 0; i < 100000; i++) {
    hugeSet.add('file:///foo/bar/' + i);
    hugeSet.add('http:///foo/bar/' + i);
}
suite.add('Loop', () => {
    const result = new Set();
    let i = 0;
    for (const uri of hugeSet) {
        i++;
        if (i === 5) {
            break;
        }
        if (!uri.startsWith('file://')) {
            continue;
        }
        result.add(uri);
    }
});
suite.add('iterare', () => {
    iterate_1.iterate(hugeSet)
        .filter(uri => uri.startsWith('file://'))
        .take(5)
        .toSet();
});
suite.add('Array method chain', () => {
    return new Set(Array.from(hugeSet)
        .filter(uri => uri.startsWith('file://'))
        .slice(0, 5));
});
suite.add('Lodash', () => {
    // Need to convert to Array first, because lodash does not support Sets
    // This uses lodash's lazy evaluation feature
    return new Set(_(Array.from(hugeSet))
        .filter((uri) => uri.startsWith('file://'))
        .take(5)
        .value());
});
suite.add('RxJS', (deferred) => {
    rxjs_1.Observable.from(Array.from(hugeSet))
        .filter((uri) => uri.startsWith('file://'))
        .take(5)
        .toArray()
        .map(arr => new Set(arr))
        .subscribe(result => {
        deferred.resolve();
    });
}, { defer: true });
suite.on('cycle', (event) => {
    console.log(String(event.target));
});
suite.on('complete', function () {
    console.log('Fastest is ' + this.filter('fastest').map('name'));
});
suite.run({ async: true });
//# sourceMappingURL=filter_take.js.map